@@ -50,7 +50,7 @@ PersonalDataPage::PersonalDataPage(Dialog *parent)
     connect(ui.nameEdit, &QLineEdit::textChanged, this, &PersonalDataPage::slotTextChanged);
     connect(ui.createAccountPb, &QPushButton::clicked, this, &PersonalDataPage::slotCreateAccountClicked);
     connect(ui.buttonGroup, &QButtonGroup::buttonClicked, this, &PersonalDataPage::slotRadioButtonClicked);
-#ifdef KDEPIM_ENTERPRISE_BUILD
+#if KDEPIM_ENTERPRISE_BUILD
     ui.checkOnlineGroupBox->setChecked(false);
 #endif
 }
@@ -176,6 +176,9 @@ void PersonalDataPage::configureSmtpAccount()
         case Ispdb::GSSAPI:
             t->setAuthenticationType(QStringLiteral("gssapi"));
             break;
+        case Ispdb::OAuth2:
+            t->setAuthenticationType(QStringLiteral("oauth2"));
+            break;
         case Ispdb::ClientIP:
             break;
         case Ispdb::NoAuth:
